[
  (block)
  (enum_declaration)
  (union_declaration)
  (struct_declaration)
  (struct)
  (parameters)
  (tuple_type)
  (call_expression)
  (switch_case)
] @indent

[
 ")"
 "]"
] @outdent

; Have to do all closing brackets separately because the one for switch statements shouldn't end.
(block "}" @outdent)
(enum_declaration "}" @outdent)
(union_declaration "}" @outdent)
(struct_declaration "}" @outdent)
(struct "}" @outdent)
