[
	(list)
	(map)
	(call_body)
	(parameter_list)
	(call_expression)
	(getter_definition)
	(setter_definition)
	(prefix_operator_definition)
	(subscript_operator_definition)
	(subscript_setter_definition)
	(infix_operator_definition)
	(method_definition)
	(constructor)
	(static_method_definition)
	(static_getter_definition)
	(attribute)
	(conditional)
	(class_body)
	(if_statement)
	(for_statement)
	(while_statement)
] @indent

[
	"}"
	"]"
	")"
] @outdent
