[
  (annotation_definition)
  (enum_definition)
  (exception_definition)
  (function_definition)
  (senum_definition)
  (service_definition)
  (struct_definition)
  (union_definition)

  (comment)
] @fold
