[
(do_statement)
(numeric_for_statement)
(generic_for_statement)
(while_statement)
(repeat_statement)
(if_statement)
(function_statement)
(record_declaration)
(interface_declaration)
(enum_declaration)
(anon_function)
(table_constructor)
] @fold

