[
    (comment)
    (note)
] @comment

[
    (date)
    (interval)
    (quantity)
] @constant.numeric.integer

((account) @variable.other.member)
((commodity) @text.literal)

"include" @keyword.local.import

[
    "account"
    "alias"
    "assert"
    "check"
    "commodity"
    "def"
    "default"
    "end"
    "eval"
    "format"
    "nomarket"
    "note"
    "payee"
    "check"
    "A"
    "Y"
    "N"
    "D"
    "C"
    "P"
] @keyword
