[
  (msgctxt)
  (msgid)
  (msgid_plural)
  (msgstr)
]@keyword

(comment) @comment
(comment (comment_reference (text) @string.special.path))
(comment (comment_flag (text) @label))

(number) @constant.numeric
(string) @string

(ERROR) @error
