;; From nvim-treesitter, contributed by @ObserverOfTime et al.

(funcdef
  (identifier) @local.definition)

(funcdefargs
  (identifier) @local.definition)

(funcname) @local.reference

(index
  (identifier) @local.reference)
