[
  (parameters)
  (template_parameters)
  (expression_statement)
  (aggregate_body)
  (function_body)
  (scope_statement)
  (block_statement)
  (case_statement)
] @indent

[
  (case)
  (default)
  "}"
  "]"
] @outdent
