[
  (true)
  (false)
] @constant.builtin.boolean
(null) @constant.builtin
(number) @constant.numeric

(member
  name: (_) @variable.other.member)

(string) @string
(comment) @comment

"," @punctuation.delimiter
[
  "["
  "]"
  "{"
  "}"
] @punctuation.bracket
