(function_definition) @local.scope
(template_definition) @local.scope
(main_component_definition) @local.scope
(block_statement) @local.scope

(parameter name: (identifier) @local.definition) @local.definition


(identifier) @local.reference