[
  (module)
  (program)
  (subroutine)
  (function)
  ; (interface)
  (if_statement)
  (do_loop_statement)
  (where_statement)
  (derived_type_definition)
  (enum)
] @indent

[
  (end_module_statement)
  (end_program_statement)
  (end_subroutine_statement)
  (end_function_statement)
  ; (end_interface_statement)
  (end_if_statement)
  (end_do_loop_statement)
  (else_clause)
  (elseif_clause)
  (end_type_statement)
  (end_enum_statement)
  (end_where_statement)
] @outdent