(function_definition) @local.scope
(constructor_definition) @local.scope
(block_statement) @local.scope

(function_definition (parameter name: (identifier) @local.definition))
(constructor_definition (parameter name: (identifier) @local.definition))
(variable_declaration name: (identifier) @local.definition)

(identifier) @local.reference
