[
  (block)
  (arguments)
  (parameter)
  (class_definition)
  (trait_definition)
  (object_definition)
  (function_definition)
  (val_definition)
  (import_declaration)
  (while_expression)
  (do_while_expression)
  (for_expression)
  (try_expression)
  (match_expression)
] @indent

[
  "}"
  "]"
  ")"
] @outdent
