(parameter) @keyword

(change_port) @function.special

(template) @variable

[
  (hex_argument)
  (ipv4_argument)
] @attribute

(numeric_argument) @constant.numeric

(index) @tag

(string_literal_argument) @string

(string_argument) @constant.character

(comment) @comment

(port_comment) @label

[
("[") 
("]")
] @punctuation.bracket
