[
  (annotation_directive)
  (array_data_directive)
  (field_definition)
  (method_definition)
  (packed_switch_directive)
  (param_directive)
  (parameter_directive)
  (sparse_switch_directive)
  (subannotation_directive)
  (list)
  "\{"
] @indent

[
  ".end annotation"
  ".end array-data"
  ".end field"
  ".end method"
  ".end packed-switch"
  ".end param"
  ".end parameter"
  ".end sparse-switch"
  ".end subannotation"
  "\}"
] @outdent

[
  (ERROR)
  (comment)
] @indent.always
