[
  (annotation_directive)
  (array_data_directive)
  (field_definition)
  (method_definition)
  (packed_switch_directive)
  (param_directive)
  (parameter_directive)
  (sparse_switch_directive)
  (subannotation_directive)
  (list)
] @fold
