[
  (arguments)
  (array)
  (assign_field)
  (assign_local)
  (assign_receiver_field)
  (binary)
  (block)
  (bounds)
  (cast)
  (class)
  (class_pattern)
  (compound_assign_field)
  (compound_assign_local)
  (compound_assign_receiver_field)
  (define_constant)
  (define_variable)
  (grouped_expression)
  (implement_trait)
  (match)
  (or_pattern)
  (reopen_class)
  (replace_field)
  (replace_local)
  (symbols)
  (trait)
  (tuple)
  (tuple_pattern)
  (type_arguments)
] @indent

[
  ")"
  "]"
  "}"
] @outdent
