[
  (struct_declaration)
  (function_declaration)
  (if_expression)
  (match_expression)
  (for_statement)
  (unsafe_expression)
  (var_declaration)
  (const_declaration)
] @indent

[
  "]"
  ")"
  "}"
] @outdent
