
(function_declaration
 (function_body_declaration
  (function_identifier
     (function_identifier
        (simple_identifier) @function.inside)))) @function.around

(comment) @comment.inside

(comment)+ @comment.around
