(pattern_char) @string
(pattern_char_escaped) @constant.character.escape

(directory_separator) @string
(directory_separator_escaped) @constant.character.escape

(negation) @operator

(wildcard_char_single) @operator
(wildcard_chars) @operator
(wildcard_chars_allow_slash) @operator

(bracket_char) @string
(bracket_char_escaped) @constant.character.escape

(bracket_negation) @operator
(bracket_range) @operator
(bracket_char_class) @keyword

[
  "["
  "]"
] @punctuation.bracket

(comment) @comment
