; This query specifies how to auto-indent logical blocks.
;
; Better documentation with diagrams is in https://docs.helix-editor.com/guides/indent.html

[
  (recipe)
  (string)
  (external_command)
] @indent @extend
