(single_line_comment) @comment
(multi_line_comment) @comment

(node
    (identifier) @variable)

(prop (identifier) @attribute)

(type (_) @type) @punctuation.bracket

(keyword) @keyword

(string) @string
(number) @constant.numeric
(boolean) @constant.builtin.boolean

"." @punctuation.delimiter

"=" @operator

"{" @punctuation.bracket
"}" @punctuation.bracket
