; inherits: python


[
  (rule_definition)
  (checkpoint_definition)
  (rule_inheritance)
  (module_definition)
] @indent

[
  (rule_definition)
  (checkpoint_definition)
  (rule_inheritance)
  (module_definition)
] @extend


(directive) @indent
(directive) @extend

(rule_import
  "with"
  ":") @indent
(rule_import
  "with"
  ":") @extend
