[
  (feature_keyword)
  (rule_keyword)
  (background_keyword)
  (scenario_keyword)
  (given_keyword)
  (when_keyword)
  (then_keyword)
  (and_keyword)
  (but_keyword)
  (asterisk_keyword)
] @keyword

(tag) @function
(doc_string) @string
(data_table) @special
(comment) @comment
