((line_comment) @injection.content
 (#set! injection.language "comment")
 (#set! injection.include-children))

((block_comment) @injection.content
 (#set! injection.language "comment")
 (#set! injection.include-children))
