[
  (model_expression)
  (tuple_expression)
  (namespace_body)
  (interface_body)
  (union_body)
  (enum_body)
  (template_arguments)
  (template_parameters)
  (operation_arguments)
] @indent.begin

[
  "}"
  ")"
  ">"
  "]"
] @indent.end
