[
 (module_definition)
 (struct_definition)
 (macro_definition)
 (function_definition)
 (compound_expression) ; begin blocks
 (let_statement)
 (if_statement)
 (for_statement)
 (while_statement)
] @fold
