((evaluation_block (prompt_line (expression) @injection.content))
 (#set! injection.language "elixir")
 (#set! injection.combined))

((result) @injection.content
 (#set! injection.language "elixir"))
