[
  (init_declarator)
  (compound_statement)
  (preproc_arg)
  (field_declaration_list)
  (case_statement)
  (conditional_expression)
  (enumerator_list)
  (struct_specifier)
  (compound_literal_expression)
] @indent

[
  "#define"
  "#ifdef"
  "#endif"
  "{"
  "}"
] @outdent
