; highlights.scm

(identifier) @keyword
(number) @constant.numeric
(comment) @comment
(raw_character) @constant.character
(literal_hex) @constant.numeric.integer
(macro_definition) @function
(label_definition) @label
(sub_label_definition) @label
(relative_pad) @constant
(label) @label
(sub_label) @label
(ERROR) @error
["[" "]" "{" "}"] @punctuation.bracket
