; inherits: wat

[
  "assert_return"
  "assert_trap"
  "assert_exhaustion"
  "assert_malformed"
  "assert_invalid"
  "assert_unlinkable"
  "assert_trap"

  "invoke"
  "get"

  "script"
  "input"
  "output"

  "binary"
  "quote"
] @keyword
