; Support for folding in Ada
;;    za     toggles folding a package, subprogram, if statement or loop

[
   (package_declaration)
   (generic_package_declaration)
   (package_body)
   (subprogram_declaration)
   (subprogram_body)
   (block_statement)
   (if_statement)
   (loop_statement)
   (gnatprep_declarative_if_statement)
   (gnatprep_if_statement)
] @fold
