(comment) @comment

((distinguishedName
  (name
    (name_componet
      (attributeTypeAndValue
        (attributeType) @comment
        (string) @type.parameter
          )))) @comment)


(dn_spec) @constant
(changerecord) @constant
(mod_spec) @constant

(attributeType) @type.parameter
(change_modify) @string

(value_spec) @keyword
