
(func_def name: (identifier) (block) @function.inside) @function.around

(param_list (_) @parameter.inside) @parameter.around

(args (_) @parameter.inside) @parameter.around

(comment) @comment.inside

(comment)+ @comment.around
