[
  "SYSCONFIG"
  "BLOCK"
  "LOCATE"
  "COMP"
  "FREQUENCY"
  "PORT"
  "IOBUF"
] @keyword

["SITE"] @keyword.storage

["="] @operator

((number) @constant.numeric)

((string) @string)
((line_comment) @comment)

