(headline) @markup.heading

(open_checkbox) @markup.list
(ongoing_checkbox) @keyword.control
(checked_checkbox) @diff.plus
(obsolete_checkbox) @comment.unused

(checked_task) @comment.unused
(obsolete_task) @comment.unused

(priority) @error
