[
  (array_creation_expression)
  (arguments)
  (formal_parameters)
  (compound_statement)
  (declaration_list)
  (binary_expression)
  (return_statement)
  (expression_statement)
  (switch_block)
  (anonymous_function_use_clause)
] @indent

[
  "}"
  ")"
  "]"
] @outdent
