[
  (struct_definition)
  (macro_definition)
  (function_definition)
  (compound_expression)
  (let_statement)
  (if_statement)
  (for_statement)
  (while_statement)
  (do_clause)
  (parameter_list)
] @indent

[
  "end"
] @outdent
