[
  (argument_list)
  (array)
  (begin)
  (block)
  (call)
  (class)
  (case)
  (elsif)
  (if)
  (hash)
  (method)
  (module)
  (singleton_class)
  (singleton_method)
] @indent

[
  ")"
  "}"
  "]"
  "end"
  "when"
] @outdent
