(section (identifier) @type.builtin)

(attribute (identifier) @attribute)
(property (path) @variable.other.member)
(constructor (identifier) @constructor)

(string) @string
(integer) @constant.numeric.integer
(float) @constant.numeric.float

(true) @constant.builtin.boolean
(false) @constant.builtin.boolean

[
  "["
  "]"
] @tag

[
  "("
  ")"
  "{"
  "}"
] @punctuation.bracket

"=" @operator

(ERROR) @error
(comment) @comment
