[
  (arguments_statement)
  (if_statement)
  (for_statement)
  (while_statement)
  (switch_statement)
  (try_statement)
  (function_definition)
  (class_definition)
  (enumeration)
  (events)
  (methods)
  (properties)
] @indent

[
  (elseif_clause)
  (else_clause)
  (case_clause)
  (otherwise_clause)
  (catch_clause)
] @indent @extend

[ "end" ] @outdent
